@@ -253,6 +253,20 @@ class BleDevice(NrfDriverObserver):
         """
         return self._default_conn_config.max_att_mtu
 
+    def set_tx_power(self, tx_power):
+        """
+        Sets the radio transmit power. This is used for all connections, advertising, active scanning, etc.
+        Method can be called at any time
+
+        Valid transmit power values are -40, -20, -16, -12, -8, -4, 0, 3, and 4 dBm
+
+        :param tx_power: The transmit power to use, in dBm
+        """
+        valid_tx_power_values = [-40, -20, -16, -12, -8, -4, 0, 3, 4]
+        if tx_power not in valid_tx_power_values:
+            raise ValueError("Invalid transmit power value {}. Must be one of: {}".format(tx_power, valid_tx_power_values))
+        self.ble_driver.ble_gap_tx_power_set(tx_power)
+
     def connect(self, peer_address, connection_params=None) -> PeripheralConnectionWaitable:
         """
         Initiates a connection to a peripheral peer with the specified connection parameters, or uses the default
@@ -260,9 +274,9 @@ class BleDevice(NrfDriverObserver):
         either times out or reports the newly connected peer
 
         :param peer_address: The address of the peer to connect to
-        :type peer_address: peer.PeerAddress
+        :type peer_address: blatann.gap.gap_types.PeerAddress
         :param connection_params: Optional connection parameters to use. If not specified, uses the set default
-        :type connection_params: peer.ConnectionParameters
+        :type connection_params: blatann.gap.gap_types.ConnectionParameters
         :return: A Waitable which can be used to wait until the connection is successful or times out. Waitable returns
                  a peer.Peripheral object
         """
@@ -326,7 +340,7 @@ class BleDevice(NrfDriverObserver):
 
     def on_driver_event(self, nrf_driver, event):
         """
-        For internal use only
+        :meta private:
         """
         if isinstance(event, nrf_events.GapEvtConnected):
             conn_params = peer.ConnectionParameters(event.conn_params.min_conn_interval_ms,
