@@ -1,7 +1,7 @@
 import time
 from typing import Iterable, List, Dict, Union, Optional, Tuple
 import logging
-from blatann.nrf import nrf_types
+from blatann.nrf import nrf_types, nrf_events
 from blatann import uuid, exceptions
 
 
@@ -215,6 +215,9 @@ class AdvertisingData(object):
 
         service_uuid16s = []
         if uuid16_data:
+            if len(uuid16_data) % 2 != 0:
+                logger.debug(f"Got odd number of bytes for UUID16 Data: {uuid16_data}. Stripping last byte")
+                uuid16_data = uuid16_data[:-1]
             for i in range(0, len(uuid16_data), 2):
                 uuid16 = (uuid16_data[i+1] << 8) | uuid16_data[i]
                 service_uuid16s.append(uuid.Uuid16(uuid16))
@@ -228,6 +231,11 @@ class AdvertisingData(object):
 
         service_uuid128s = []
         if uuid128_data:
+            leftover_bytes = len(uuid128_data) % 16
+            if leftover_bytes != 0:
+                logger.debug(f"Got invalid multiple for UUID128 data: {uuid128_data}. "
+                             f"Stripping off {leftover_bytes} bytes")
+                uuid128_data = uuid128_data[:-leftover_bytes]
             for i in range(0, len(uuid128_data), 16):
                 uuid128 = uuid128_data[i:i+16][::-1]
                 service_uuid128s.append(uuid.Uuid128(uuid128))
@@ -366,11 +374,10 @@ class ScanReportCollection(object):
         self._all_scans = []
         self._scans_by_peer_address = {}
 
-    def update(self, adv_report) -> ScanReport:
+    def update(self, adv_report: nrf_events.GapEvtAdvReport) -> ScanReport:
         """
         Used internally to update the collection with a new advertising report received
 
-        :type adv_report: nrf_events.GapEvtAdvReport
         :return: The Scan Report created from the advertising report
         """
         scan_entry = ScanReport(adv_report)
@@ -379,6 +386,6 @@ class ScanReportCollection(object):
         self._all_scans.append(scan_entry)
         if adv_report.peer_addr in self._scans_by_peer_address.keys():
             self._scans_by_peer_address[adv_report.peer_addr].update(adv_report)
-        else:
+        elif adv_report.peer_addr.addr_type != nrf_types.BLEGapAddrTypes.anonymous:
             self._scans_by_peer_address[adv_report.peer_addr] = ScanReport(adv_report)
         return scan_entry
