@@ -309,7 +309,8 @@ class NrfDriver(object):
             name = name.encode("utf8")
         write_perm = BLEGapSecMode(0, 0).to_c()
         length = len(name)
-        data = util.list_to_uint8_array(name).cast()
+        data_array = util.list_to_uint8_array(name)
+        data = data_array.cast()
         return driver.sd_ble_gap_device_name_set(self.rpc_adapter, write_perm, data, length)
 
     @NordicSemiErrorCheck
@@ -324,6 +325,11 @@ class NrfDriver(object):
         params = conn_params.to_c()
         return driver.sd_ble_gap_ppcp_set(self.rpc_adapter, params)
 
+    @NordicSemiErrorCheck
+    @wrapt.synchronized
+    def ble_gap_tx_power_set(self, tx_power):
+        return driver.sd_ble_gap_tx_power_set(self.rpc_adapter, tx_power)
+
     @NordicSemiErrorCheck
     @wrapt.synchronized
     def ble_gap_adv_start(self, adv_params=None, conn_cfg_tag=0):
@@ -358,6 +364,29 @@ class NrfDriver(object):
     def ble_gap_scan_stop(self):
         return driver.sd_ble_gap_scan_stop(self.rpc_adapter)
 
+    @NordicSemiErrorCheck
+    @wrapt.synchronized
+    def ble_gap_rssi_start(self, conn_handle, threshold_dbm, skip_count):
+        if threshold_dbm is None:
+            threshold_dbm = driver.BLE_GAP_RSSI_THRESHOLD_INVALID
+        return driver.sd_ble_gap_rssi_start(self.rpc_adapter, conn_handle, threshold_dbm, skip_count)
+
+    @NordicSemiErrorCheck
+    @wrapt.synchronized
+    def ble_gap_rssi_stop(self, conn_handle):
+        return driver.sd_ble_gap_rssi_stop(self.rpc_adapter, conn_handle)
+
+    @NordicSemiErrorCheck
+    @wrapt.synchronized
+    def ble_gap_rssi_get(self, conn_handle):
+        rssi = driver.new_int8()
+        err = driver.sd_ble_gap_rssi_get(self.rpc_adapter, conn_handle, rssi)
+        if err == driver.NRF_SUCCESS:
+            rssi = driver.int8_value(rssi)
+        else:
+            rssi = None
+        return err, rssi
+
     @NordicSemiErrorCheck
     @wrapt.synchronized
     def ble_gap_connect(self, address, scan_params=None, conn_params=None, conn_cfg_tag=0):
@@ -441,8 +470,10 @@ class NrfDriver(object):
     @NordicSemiErrorCheck
     @wrapt.synchronized
     def ble_gap_auth_key_reply(self, conn_handle, key_type, key):
+        key_data = None
         if key is not None:
-            key_buf = util.list_to_uint8_array(key).cast()
+            key_data = util.list_to_uint8_array(key)
+            key_buf = key_data.cast()
         else:
             key_buf = None
         return driver.sd_ble_gap_auth_key_reply(self.rpc_adapter, conn_handle, key_type, key_buf)
@@ -571,8 +602,10 @@ class NrfDriver(object):
     @NordicSemiErrorCheck
     @wrapt.synchronized
     def ble_gatts_sys_attr_set(self, conn_handle, sys_attr_data, flags=0):
+        data_array = None
         if sys_attr_data is not None:
-            data = util.list_to_uint8_array(sys_attr_data).cast()
+            data_array = util.list_to_uint8_array(sys_attr_data)
+            data = data_array.cast()
             length = len(sys_attr_data)
         else:
             data = None
