@@ -60,10 +60,11 @@ conn_timeout_range = TimeRange("Connection Timeout",
 
 
 class BLEGapAdvParams(object):
-    def __init__(self, interval_ms, timeout_s, advertising_type=BLEGapAdvType.connectable_undirected):
+    def __init__(self, interval_ms, timeout_s, advertising_type=BLEGapAdvType.connectable_undirected, channel_mask=None):
         self.interval_ms = interval_ms
         self.timeout_s = timeout_s
         self.advertising_type = advertising_type
+        self.channel_mask = channel_mask or [False, False, False]
 
     def to_c(self):
         adv_params = driver.ble_gap_adv_params_t()
@@ -75,13 +76,22 @@ class BLEGapAdvParams(object):
                                                  util.UNIT_0_625_MS)
         adv_params.timeout = self.timeout_s
 
+        mask = driver.ble_gap_adv_ch_mask_t()
+        mask.ch_37_off = self.channel_mask[0]
+        mask.ch_38_off = self.channel_mask[1]
+        mask.ch_39_off = self.channel_mask[2]
+        adv_params.channel_mask = mask
+
         return adv_params
 
     def __repr__(self):
-        return "{!r}(type: {!r}, interval: {!r}ms, timeout: {!r}s)".format(self.__class__.__name__,
-                                                                           self.advertising_type,
-                                                                           self.interval_ms,
-                                                                           self.timeout_s)
+        ch_mask_str = "".join([str(int(c)) for c in self.channel_mask])
+        return "{!r}(type: {!r}, interval: {!r}ms, timeout: {!r}s, ch mask: {})".format(
+            self.__class__.__name__,
+            self.advertising_type,
+            self.interval_ms,
+            self.timeout_s,
+            ch_mask_str)
 
 
 class BLEGapScanParams(object):
@@ -111,6 +121,14 @@ class BLEGapConnParams(object):
         self.conn_sup_timeout_ms = conn_sup_timeout_ms
         self.slave_latency = slave_latency
 
+    def validate(self):
+        conn_interval_range.validate(self.min_conn_interval_ms)
+        conn_interval_range.validate(self.max_conn_interval_ms)
+        conn_timeout_range.validate(self.conn_sup_timeout_ms)
+        if self.min_conn_interval_ms > self.max_conn_interval_ms:
+            raise ValueError(f"Minimum connection interval must be <= max connection interval "
+                             f"(Min: {self.min_conn_interval_ms} Max: {self.max_conn_interval_ms}")
+
     @classmethod
     def from_c(cls, conn_params):
         return cls(min_conn_interval_ms=util.units_to_msec(conn_params.min_conn_interval,
@@ -133,6 +151,9 @@ class BLEGapConnParams(object):
 
         return conn_params
 
+    def __repr__(self):
+        return str(self)
+
     def __str__(self):
         return "{}(interval: [{!r}-{!r}] ms, timeout: {!r} ms, latency: {!r})".format(self.__class__.__name__,
                                                                                       self.min_conn_interval_ms,
@@ -146,6 +167,7 @@ class BLEGapAddrTypes(IntEnum):
     random_static = int(driver.BLE_GAP_ADDR_TYPE_RANDOM_STATIC)
     random_private_resolvable = int(driver.BLE_GAP_ADDR_TYPE_RANDOM_PRIVATE_RESOLVABLE)
     random_private_non_resolvable = int(driver.BLE_GAP_ADDR_TYPE_RANDOM_PRIVATE_NON_RESOLVABLE)
+    anonymous = 127  # This isn't defined in the headers for Softdevice v5 and was added in v6
 
 
 class BLEGapAddr(object):
@@ -196,6 +218,8 @@ class BLEGapAddr(object):
             return 'res'
         elif self.addr_type == BLEGapAddrTypes.random_static:
             return 'static'
+        elif self.addr_type == BLEGapAddrTypes.anonymous:
+            return 'anonymous'
         else:
             return 'err'
 
@@ -218,7 +242,8 @@ class BLEGapAddr(object):
             BLEGapAddrTypes.public: "p",
             BLEGapAddrTypes.random_static: "s",
             BLEGapAddrTypes.random_private_resolvable: "r",
-            BLEGapAddrTypes.random_private_non_resolvable: "n"
+            BLEGapAddrTypes.random_private_non_resolvable: "n",
+            BLEGapAddrTypes.anonymous: "a"
         }[self.addr_type]
 
     def __str__(self):
